"""
PyCorrAna - Python Correlation Analysis Toolkit
===============================================

一个方便快速入手的Python相关性分析工具，核心在于：
自动化常规操作、降低决策成本、一键输出关键结果。

主要功能
--------
- 数据接入与基础清洗：自动识别格式、缺失值处理、类型推断
- 相关性计算引擎：自动选择最优相关系数方法
- 可视化核心：热力图、散点图矩阵、箱线图
- 结果导出：CSV/Excel、文本摘要、控制台友好输出

快速开始
--------
>>> from pycorrana import quick_corr
>>> import pandas as pd
>>> df = pd.read_csv('data.csv')
>>> result = quick_corr(df, target='sales')

或者使用交互式CLI：
$ pycorrana-interactive
"""

__version__ = "0.1.10"
__author__ = "SidneyZhang<zly@lyzhang.me>"

from .core.analyzer import quick_corr, CorrAnalyzer
from .core.partial_corr import (
    partial_corr, 
    partial_corr_matrix,
    semipartial_corr,
    PartialCorrAnalyzer
)
from .core.nonlinear import (
    distance_correlation, 
    mutual_info_score,
    maximal_information_coefficient,
    nonlinear_dependency_report,
    NonlinearAnalyzer
)
from .core.cca import (
    cca,
    cca_permutation_test,
    CCAAnalyzer
)
from .datasets import load_iris, load_titanic, load_wine, make_correlated_data, list_datasets

__all__ = [
    'quick_corr',
    'CorrAnalyzer',
    'partial_corr',
    'partial_corr_matrix',
    'semipartial_corr',
    'PartialCorrAnalyzer',
    'distance_correlation',
    'mutual_info_score',
    'maximal_information_coefficient',
    'nonlinear_dependency_report',
    'NonlinearAnalyzer',
    'cca',
    'cca_permutation_test',
    'CCAAnalyzer',
    'load_iris',
    'load_titanic',
    'load_wine',
    'make_correlated_data',
    'list_datasets',
]



"""
非线性依赖检测模块
==================
提供距离相关、互信息等非线性依赖检测方法。
"""

import warnings
from typing import Optional, List, TYPE_CHECKING
import numpy as np
import pandas as pd
from scipy.spatial.distance import pdist, squareform
from scipy.stats import entropy
from sklearn.feature_selection import mutual_info_regression

if TYPE_CHECKING:
    from ..utils.large_data import LargeDataConfig


SAMPLE_SIZE_NONLINEAR = 20_000


def distance_correlation(x: np.ndarray, 
                        y: np.ndarray,
                        return_pvalue: bool = False,
                        n_permutations: int = 1000,
                        confidence_level: float = 0.95,
                        n_bootstrap: int = 500) -> dict:
    """
    计算距离相关系数（Distance Correlation）。
    
    距离相关可以检测变量间的任意类型依赖关系（包括非线性），
    当且仅当变量独立时距离相关为0。
    
    Parameters
    ----------
    x, y : np.ndarray
        两个变量的观测值
    return_pvalue : bool, default=False
        是否计算p值（通过置换检验）
    n_permutations : int, default=1000
        置换检验次数
    confidence_level : float, default=0.95
        置信区间水平
    n_bootstrap : int, default=500
        Bootstrap抽样次数（用于计算置信区间）
        
    Returns
    -------
    dict
        包含距离相关系数、p值和置信区间的字典
        
    Examples
    --------
    >>> x = np.random.randn(100)
    >>> y = x**2 + np.random.randn(100) * 0.1
    >>> result = distance_correlation(x, y, return_pvalue=True)
    >>> print(f"dCor: {result['dcor']:.4f}, p-value: {result['p_value']:.4f}")
    >>> print(f"95% CI: {result['confidence_interval']}")
    
    References
    ----------
    Székely, G.J., Rizzo, M.L., and Bakirov, N.K. (2007)
    "Measuring and testing dependence by correlation of distances"
    Annals of Statistics, Vol. 35 No. 6, pp. 2769-2794
    """
    x = np.asarray(x).flatten()
    y = np.asarray(y).flatten()
    
    mask = ~(np.isnan(x) | np.isnan(y))
    x, y = x[mask], y[mask]
    
    n = len(x)
    
    if n < 3:
        return {'dcor': np.nan, 'p_value': np.nan, 'confidence_interval': (np.nan, np.nan), 'n': n}
    
    def distance_matrix(a):
        return squareform(pdist(a.reshape(-1, 1), metric='euclidean'))
    
    def center_distance_matrix(D):
        row_mean = D.mean(axis=1, keepdims=True)
        col_mean = D.mean(axis=0, keepdims=True)
        grand_mean = D.mean()
        return D - row_mean - col_mean + grand_mean
    
    def _compute_dcor(x_vals, y_vals):
        Dx = distance_matrix(x_vals)
        Dy = distance_matrix(y_vals)
        A = center_distance_matrix(Dx)
        B = center_distance_matrix(Dy)
        dcov_sq = np.mean(A * B)
        dvar_x = np.mean(A * A)
        dvar_y = np.mean(B * B)
        if dvar_x > 0 and dvar_y > 0:
            return np.sqrt(dcov_sq) / np.sqrt(np.sqrt(dvar_x) * np.sqrt(dvar_y))
        return 0.0
    
    Dx = distance_matrix(x)
    Dy = distance_matrix(y)
    A = center_distance_matrix(Dx)
    B = center_distance_matrix(Dy)
    
    dcov_sq = np.mean(A * B)
    dvar_x = np.mean(A * A)
    dvar_y = np.mean(B * B)
    
    if dvar_x > 0 and dvar_y > 0:
        dcor = np.sqrt(dcov_sq) / np.sqrt(np.sqrt(dvar_x) * np.sqrt(dvar_y))
    else:
        dcor = 0.0
    
    result = {'dcor': dcor, 'n': n}
    
    if return_pvalue:
        count = 0
        dcor_obs = dcor
        
        for _ in range(n_permutations):
            y_perm = np.random.permutation(y)
            Dy_perm = distance_matrix(y_perm)
            B_perm = center_distance_matrix(Dy_perm)
            
            dcov_sq_perm = np.mean(A * B_perm)
            dvar_y_perm = np.mean(B_perm * B_perm)
            
            if dvar_x > 0 and dvar_y_perm > 0:
                dcor_perm = np.sqrt(dcov_sq_perm) / np.sqrt(np.sqrt(dvar_x) * np.sqrt(dvar_y_perm))
            else:
                dcor_perm = 0.0
            
            if dcor_perm >= dcor_obs:
                count += 1
        
        p_value = (count + 1) / (n_permutations + 1)
        result['p_value'] = p_value
    
    if n >= 30:
        dcor_bootstrap = []
        
        for _ in range(n_bootstrap):
            indices = np.random.choice(n, size=n, replace=True)
            x_boot = x[indices]
            y_boot = y[indices]
            
            try:
                dcor_boot = _compute_dcor(x_boot, y_boot)
                dcor_bootstrap.append(dcor_boot)
            except Exception:
                pass
        
        if dcor_bootstrap:
            alpha = 1 - confidence_level
            lower = np.percentile(dcor_bootstrap, alpha / 2 * 100)
            upper = np.percentile(dcor_bootstrap, (1 - alpha / 2) * 100)
            result['confidence_interval'] = (lower, upper)
        else:
            result['confidence_interval'] = (np.nan, np.nan)
    else:
        result['confidence_interval'] = (np.nan, np.nan)
    
    return result


def distance_correlation_matrix(data: pd.DataFrame,
                                columns: Optional[List[str]] = None) -> pd.DataFrame:
    """
    计算距离相关矩阵。
    
    Parameters
    ----------
    data : pd.DataFrame
        输入数据
    columns : list, optional
        要分析的列
        
    Returns
    -------
    pd.DataFrame
        距离相关系数矩阵
    """
    if columns is None:
        columns = data.select_dtypes(include=[np.number]).columns.tolist()
    
    n_cols = len(columns)
    dcor_matrix = pd.DataFrame(np.eye(n_cols), index=columns, columns=columns)
    
    for i, col1 in enumerate(columns):
        for j, col2 in enumerate(columns[i+1:], i+1):
            result = distance_correlation(
                data[col1].values, 
                data[col2].values
            )
            dcor = result['dcor']
            dcor_matrix.iloc[i, j] = dcor
            dcor_matrix.iloc[j, i] = dcor
    
    return dcor_matrix


def mutual_info_score(x: np.ndarray,
                     y: np.ndarray,
                     discrete_features: bool = False,
                     n_neighbors: int = 3,
                     return_pvalue: bool = False,
                     n_permutations: int = 1000) -> dict:
    """
    计算互信息分数。
    
    互信息衡量两个变量共享的信息量，可以检测非线性依赖关系。
    
    Parameters
    ----------
    x, y : np.ndarray
        两个变量的观测值
    discrete_features : bool, default=False
        x是否为离散变量
    n_neighbors : int, default=3
        KNN估计的邻居数
    return_pvalue : bool, default=False
        是否计算p值（通过置换检验）
    n_permutations : int, default=1000
        置换检验次数
        
    Returns
    -------
    dict
        包含互信息分数、p值和置信区间的字典
        
    Examples
    --------
    >>> x = np.random.randn(100)
    >>> y = np.sin(x) + np.random.randn(100) * 0.1
    >>> result = mutual_info_score(x, y, return_pvalue=True)
    >>> print(f"MI: {result['mi']:.4f}, Normalized: {result['mi_normalized']:.4f}, p-value: {result['p_value']:.4f}")
    """
    x = np.asarray(x).flatten()
    y = np.asarray(y).flatten()
    
    # 删除缺失值
    mask = ~(np.isnan(x) | np.isnan(y))
    x, y = x[mask], y[mask]
    
    n = len(x)
    
    if n < 3:
        return {'mi': 0.0, 'mi_normalized': 0.0, 'n': n, 'p_value': np.nan, 'confidence_interval': (np.nan, np.nan)}
    
    # 使用sklearn的互信息计算
    try:
        mi = mutual_info_regression(
            x.reshape(-1, 1), 
            y,
            discrete_features=discrete_features,
            n_neighbors=n_neighbors,
            random_state=42
        )[0]
    except Exception as e:
        warnings.warn(f"互信息计算失败: {e}")
        mi = 0.0
    
    # 归一化互信息（0-1范围）
    # 使用最小熵进行归一化
    from sklearn.metrics import mutual_info_score as sklearn_mi
    
    # 离散化用于计算熵
    x_discrete = pd.qcut(x, q=min(10, n//5), duplicates='drop', labels=False)
    y_discrete = pd.qcut(y, q=min(10, n//5), duplicates='drop', labels=False)
    
    # 计算熵
    def calc_entropy(a):
        probs = np.bincount(a) / len(a)
        return entropy(probs[probs > 0])
    
    h_x = calc_entropy(x_discrete)
    h_y = calc_entropy(y_discrete)
    
    # 归一化
    if h_x > 0 and h_y > 0:
        mi_normalized = mi / min(h_x, h_y)
    else:
        mi_normalized = 0.0
    
    result = {
        'mi': mi,
        'mi_normalized': mi_normalized,
        'entropy_x': h_x,
        'entropy_y': h_y,
        'n': n
    }
    
    # 计算p值（置换检验）
    if return_pvalue:
        count = 0
        mi_obs = mi
        
        for _ in range(n_permutations):
            y_perm = np.random.permutation(y)
            try:
                mi_perm = mutual_info_regression(
                    x.reshape(-1, 1), 
                    y_perm,
                    discrete_features=discrete_features,
                    n_neighbors=n_neighbors,
                    random_state=42
                )[0]
            except Exception:
                mi_perm = 0.0
            
            if mi_perm >= mi_obs:
                count += 1
        
        p_value = (count + 1) / (n_permutations + 1)
        result['p_value'] = p_value
    
    # 计算置信区间（基于Bootstrap）
    if n >= 30:
        n_bootstrap = 1000
        mi_bootstrap = []
        mi_normalized_bootstrap = []
        
        for _ in range(n_bootstrap):
            # 有放回抽样
            indices = np.random.choice(n, size=n, replace=True)
            x_boot = x[indices]
            y_boot = y[indices]
            
            try:
                mi_boot = mutual_info_regression(
                    x_boot.reshape(-1, 1), 
                    y_boot,
                    discrete_features=discrete_features,
                    n_neighbors=n_neighbors,
                    random_state=42
                )[0]
            except Exception:
                mi_boot = 0.0
            
            mi_bootstrap.append(mi_boot)
            
            # 计算归一化互信息
            x_boot_discrete = pd.qcut(x_boot, q=min(10, len(x_boot)//5), duplicates='drop', labels=False)
            y_boot_discrete = pd.qcut(y_boot, q=min(10, len(y_boot)//5), duplicates='drop', labels=False)
            
            h_x_boot = calc_entropy(x_boot_discrete)
            h_y_boot = calc_entropy(y_boot_discrete)
            
            if h_x_boot > 0 and h_y_boot > 0:
                mi_normalized_boot = mi_boot / min(h_x_boot, h_y_boot)
            else:
                mi_normalized_boot = 0.0
            
            mi_normalized_bootstrap.append(mi_normalized_boot)
        
        # 计算95%置信区间
        ci_mi = np.percentile(mi_bootstrap, [2.5, 97.5])
        ci_mi_normalized = np.percentile(mi_normalized_bootstrap, [2.5, 97.5])
        
        result['confidence_interval'] = (ci_mi[0], ci_mi[1])
        result['confidence_interval_normalized'] = (ci_mi_normalized[0], ci_mi_normalized[1])
    else:
        result['confidence_interval'] = (np.nan, np.nan)
        result['confidence_interval_normalized'] = (np.nan, np.nan)
    
    return result


def mutual_info_matrix(data: pd.DataFrame,
                      columns: Optional[List[str]] = None,
                      normalized: bool = True) -> pd.DataFrame:
    """
    计算互信息矩阵。
    
    Parameters
    ----------
    data : pd.DataFrame
        输入数据
    columns : list, optional
        要分析的列
    normalized : bool, default=True
        是否返回归一化互信息
        
    Returns
    -------
    pd.DataFrame
        互信息矩阵
    """
    if columns is None:
        columns = data.select_dtypes(include=[np.number]).columns.tolist()
    
    n_cols = len(columns)
    mi_matrix = pd.DataFrame(np.zeros((n_cols, n_cols)), index=columns, columns=columns)
    
    for i, col1 in enumerate(columns):
        for j, col2 in enumerate(columns[i:], i):
            result = mutual_info_score(
                data[col1].values,
                data[col2].values
            )
            
            if normalized:
                mi = result['mi_normalized']
            else:
                mi = result['mi']
            
            mi_matrix.iloc[i, j] = mi
            mi_matrix.iloc[j, i] = mi
    
    return mi_matrix


def _optimal_partition_1d(sorted_values: np.ndarray, k: int) -> np.ndarray:
    """
    使用动态规划找到一维数据的最优划分边界。
    
    目标是找到k-1个边界点，使得划分后的熵最小（信息量最大）。
    
    Parameters
    ----------
    sorted_values : np.ndarray
        已排序的值
    k : int
        划分区间数
        
    Returns
    -------
    np.ndarray
        最优边界位置（索引）
    """
    n = len(sorted_values)
    if k <= 1 or n < k:
        return np.array([])
    
    unique_vals, counts = np.unique(sorted_values, return_counts=True)
    n_unique = len(unique_vals)
    
    if n_unique <= k:
        boundaries = np.arange(1, n_unique)
        return boundaries
    
    cumsum = np.cumsum(counts)
    total = cumsum[-1]
    
    def calc_entropy_range(start: int, end: int) -> float:
        if start >= end:
            return 0.0
        count = cumsum[end] - (cumsum[start - 1] if start > 0 else 0)
        if count == 0:
            return 0.0
        p = count / total
        return -p * np.log(p)
    
    dp = np.full((n_unique + 1, k + 1), -np.inf)
    split = np.zeros((n_unique + 1, k + 1), dtype=int)
    
    for i in range(1, n_unique + 1):
        dp[i, 1] = calc_entropy_range(0, i - 1)
    
    for j in range(2, k + 1):
        for i in range(j, n_unique + 1):
            for t in range(j - 1, i):
                val = dp[t, j - 1] + calc_entropy_range(t, i - 1)
                if val > dp[i, j]:
                    dp[i, j] = val
                    split[i, j] = t
    
    boundaries = []
    i, j = n_unique, k
    while j > 1:
        boundaries.append(split[i, j])
        i = split[i, j]
        j -= 1
    
    boundaries = sorted(boundaries)
    return np.array(boundaries)


def _compute_mutual_info_discrete(x_discrete: np.ndarray, y_discrete: np.ndarray) -> float:
    """
    计算离散变量的互信息。
    
    Parameters
    ----------
    x_discrete, y_discrete : np.ndarray
        离散化后的变量
        
    Returns
    -------
    float
        互信息值
    """
    n = len(x_discrete)
    
    joint_counts = {}
    for i in range(n):
        key = (x_discrete[i], y_discrete[i])
        joint_counts[key] = joint_counts.get(key, 0) + 1
    
    x_counts = {}
    y_counts = {}
    for (xi, yi), count in joint_counts.items():
        x_counts[xi] = x_counts.get(xi, 0) + count
        y_counts[yi] = y_counts.get(yi, 0) + count
    
    mi = 0.0
    for (xi, yi), count in joint_counts.items():
        p_xy = count / n
        p_x = x_counts[xi] / n
        p_y = y_counts[yi] / n
        mi += p_xy * np.log(p_xy / (p_x * p_y))
    
    return mi


def _find_optimal_grid(x: np.ndarray, y: np.ndarray, i: int, j: int) -> float:
    """
    在i×j网格下找到最优划分并计算最大互信息。
    
    Parameters
    ----------
    x, y : np.ndarray
        原始数据
    i, j : int
        网格分辨率
        
    Returns
    -------
    float
        最优划分下的互信息
    """
    n = len(x)
    
    sort_idx_x = np.argsort(x)
    x_sorted = x[sort_idx_x]
    y_by_x = y[sort_idx_x]
    
    x_boundaries = _optimal_partition_1d(x_sorted, i)
    
    if len(x_boundaries) == 0:
        x_discrete = np.zeros(n, dtype=int)
    else:
        x_discrete = np.searchsorted(x_boundaries, np.arange(n))
        x_discrete = np.searchsorted(x_boundaries, np.searchsorted(x_sorted, x))
    
    sort_idx_y = np.argsort(y)
    y_sorted = y[sort_idx_y]
    x_by_y = x[sort_idx_y]
    
    y_boundaries = _optimal_partition_1d(y_sorted, j)
    
    if len(y_boundaries) == 0:
        y_discrete = np.zeros(n, dtype=int)
    else:
        y_discrete = np.searchsorted(y_boundaries, np.searchsorted(y_sorted, y))
    
    mi = _compute_mutual_info_discrete(x_discrete, y_discrete)
    
    return mi


def _compute_mic_core(x: np.ndarray, y: np.ndarray, B: Optional[float] = None) -> dict:
    """
    计算MIC的核心函数。
    
    MIC = max_{i*j < B} I*(X,Y,i,j) / log(min(i,j))
    
    Parameters
    ----------
    x, y : np.ndarray
        输入数据
    B : float, optional
        网格复杂度上限，默认为n^0.6
        
    Returns
    -------
    dict
        包含MIC及相关统计量的字典
    """
    n = len(x)
    
    if B is None:
        B = n ** 0.6
    
    B = int(B)
    B = max(B, 4)
    
    mic = 0.0
    best_i, best_j = 2, 2
    mas = 0.0
    mev = 0.0
    
    max_grid = min(B, int(np.sqrt(n)))
    max_grid = max(max_grid, 2)
    
    scores_matrix = {}
    
    for i in range(2, max_grid + 1):
        for j in range(2, max_grid + 1):
            if i * j > B:
                continue
            
            mi_optimal = _find_optimal_grid(x, y, i, j)
            
            normalization = np.log(min(i, j))
            if normalization > 0:
                score = mi_optimal / normalization
            else:
                score = 0.0
            
            scores_matrix[(i, j)] = score
            
            if score > mic:
                mic = score
                best_i, best_j = i, j
            
            if i == j:
                if score > mas:
                    mas = score
    
    if mic > 0:
        for (i, j), score in scores_matrix.items():
            if score > 0:
                ratio = score / mic
                if ratio > mev:
                    mev = ratio
    
    mcn = best_i * best_j
    
    return {
        'mic': mic,
        'mas': mas,
        'mev': mev,
        'mcn': mcn,
        'best_grid': (best_i, best_j)
    }


def maximal_information_coefficient(x: np.ndarray,
                                   y: np.ndarray,
                                   B: Optional[float] = None,
                                   return_pvalue: bool = False,
                                   n_permutations: int = 1000,
                                   confidence_level: float = 0.95,
                                   n_bootstrap: int = 500) -> dict:
    """
    计算最大信息系数（Maximal Information Coefficient, MIC）。
    
    MIC可以检测各种函数关系的强度，范围在[0, 1]。
    使用完整的MIC算法实现，包括最优网格划分和归一化。
    
    核心公式：
    MIC(X,Y) = max_{i*j < B} I*(X,Y,i,j) / log(min(i,j))
    
    其中：
    - i, j：X轴和Y轴的网格划分数量
    - B = n^0.6：网格复杂度上限
    - I*：在i×j网格下的最大互信息
    - 分母log(min(i,j))：归一化因子
    
    .. warning::
       当前版本为纯 Python 实现，没有特殊优化，计算速度较慢。
       对于大数据集（n > 1000），建议先进行采样处理。
    
    Parameters
    ----------
    x, y : np.ndarray
        两个变量的观测值
    B : float, optional
        网格复杂度上限，默认为n^0.6
    return_pvalue : bool, default=False
        是否计算p值（通过置换检验）
    n_permutations : int, default=1000
        置换检验次数
    confidence_level : float, default=0.95
        置信区间水平
    n_bootstrap : int, default=500
        Bootstrap抽样次数
        
    Returns
    -------
    dict
        包含以下键的字典：
        - mic: MIC值，范围[0, 1]
        - mas: 最大对称得分（Maximum Asymmetry Score）
        - mev: 最大边缘值（Maximum Edge Value）
        - mcn: 最大网格数（Maximum Cell Number）
        - n: 样本量
        - p_value: p值（如果return_pvalue=True）
        - confidence_interval: 置信区间（如果样本量足够）
        
    Examples
    --------
    >>> x = np.random.randn(100)
    >>> y = x**2 + np.random.randn(100) * 0.1
    >>> result = maximal_information_coefficient(x, y, return_pvalue=True)
    >>> print(f"MIC: {result['mic']:.4f}, p-value: {result['p_value']:.4f}")
    
    对于大数据集，建议先采样：
    
    >>> from pycorrana.utils import smart_sample
    >>> sampled_df = smart_sample(df, sample_size=500)
    >>> result = maximal_information_coefficient(sampled_df['x'], sampled_df['y'])
    
    References
    ----------
    Reshef et al. (2011) "Detecting Novel Associations in Large Data Sets"
    Science, 334(6062), 1518-1524
    """
    x = np.asarray(x).flatten()
    y = np.asarray(y).flatten()
    
    mask = ~(np.isnan(x) | np.isnan(y))
    x, y = x[mask], y[mask]
    
    n = len(x)
    
    if n < 10:
        base_result = {
            'mic': np.nan,
            'mas': np.nan,
            'mev': np.nan,
            'mcn': np.nan,
            'n': n,
            'confidence_interval': (np.nan, np.nan)
        }
        if return_pvalue:
            base_result['p_value'] = np.nan
        return base_result
    
    result = _compute_mic_core(x, y, B)
    result['n'] = n
    
    if return_pvalue:
        count = 0
        mic_obs = result['mic']
        
        for _ in range(n_permutations):
            y_perm = np.random.permutation(y)
            perm_result = _compute_mic_core(x, y_perm, B)
            if perm_result['mic'] >= mic_obs:
                count += 1
        
        p_value = (count + 1) / (n_permutations + 1)
        result['p_value'] = p_value
    
    if n >= 30:
        mic_bootstrap = []
        
        for _ in range(n_bootstrap):
            indices = np.random.choice(n, size=n, replace=True)
            x_boot = x[indices]
            y_boot = y[indices]
            
            boot_result = _compute_mic_core(x_boot, y_boot, B)
            mic_bootstrap.append(boot_result['mic'])
        
        alpha = 1 - confidence_level
        lower = np.percentile(mic_bootstrap, alpha / 2 * 100)
        upper = np.percentile(mic_bootstrap, (1 - alpha / 2) * 100)
        
        result['confidence_interval'] = (lower, upper)
    else:
        result['confidence_interval'] = (np.nan, np.nan)
    
    return result


def nonlinear_dependency_report(data: pd.DataFrame,
                               columns: Optional[List[str]] = None,
                               methods: List[str] = ['dcor', 'mi', 'mic'],
                               top_n: int = 10,
                               sample_size: int = SAMPLE_SIZE_NONLINEAR,
                               random_state: int = 42,
                               verbose: bool = True) -> pd.DataFrame:
    """
    生成非线性依赖检测报告。
    
    Parameters
    ----------
    data : pd.DataFrame
        输入数据
    columns : list, optional
        要分析的列
    methods : list, default=['dcor', 'mi', 'mic']
        要使用的检测方法
    top_n : int, default=10
        显示前N个结果
    sample_size : int, default=20000
        大数据集采样大小，设为None或0禁用采样
    random_state : int, default=42
        随机种子
    verbose : bool, default=True
        是否输出信息
        
    Returns
    -------
    pd.DataFrame
        检测报告
    """
    if columns is None:
        columns = data.select_dtypes(include=[np.number]).columns.tolist()
    
    n_rows = len(data)
    if sample_size and sample_size > 0 and n_rows > sample_size:
        data = data.sample(n=sample_size, random_state=random_state)
        if verbose:
            print(f"大数据集检测: 采样 {n_rows} -> {sample_size} 行")
    
    results = []
    
    for i, col1 in enumerate(columns):
        for col2 in columns[i+1:]:
            x = data[col1].values
            y = data[col2].values
            
            row = {'var1': col1, 'var2': col2}
            
            if 'dcor' in methods:
                dcor_result = distance_correlation(x, y)
                row['dCor'] = dcor_result['dcor']
            
            if 'mi' in methods:
                mi_result = mutual_info_score(x, y)
                row['MI'] = mi_result['mi_normalized']
            
            if 'mic' in methods:
                mic_result = maximal_information_coefficient(x, y)
                row['MIC'] = mic_result['mic']
            
            results.append(row)
    
    df = pd.DataFrame(results)
    
    score_cols = [c for c in df.columns if c not in ['var1', 'var2']]
    if score_cols:
        df['avg_score'] = df[score_cols].mean(axis=1)
        df = df.sort_values('avg_score', ascending=False)
    
    return df.head(top_n)


class NonlinearAnalyzer:
    """
    非线性依赖分析器类
    
    提供非线性依赖检测的完整流程。
    
    Parameters
    ----------
    data : pd.DataFrame
        输入数据
    verbose : bool, default=True
        是否输出详细信息
    sample_size : int, default=20000
        大数据集采样大小，设为None或0禁用采样
        
    Examples
    --------
    >>> analyzer = NonlinearAnalyzer(df)
    >>> result = analyzer.analyze_pair('X', 'Y')
    >>> report = analyzer.generate_report()
    """
    
    def __init__(self, 
                 data: pd.DataFrame, 
                 verbose: bool = True,
                 sample_size: int = SAMPLE_SIZE_NONLINEAR):
        """
        Parameters
        ----------
        data : pd.DataFrame
            输入数据
        verbose : bool, default=True
            是否输出详细信息
        sample_size : int, default=20000
            大数据集采样大小
        """
        self.original_data = data.copy()
        self.verbose = verbose
        self.sample_size = sample_size
        self._sampled = False
        
        n_rows = len(data)
        if sample_size and sample_size > 0 and n_rows > sample_size:
            self.data = data.sample(n=sample_size, random_state=42)
            self._sampled = True
            if verbose:
                print(f"大数据集检测: 采样 {n_rows} -> {sample_size} 行")
        else:
            self.data = data.copy()
        
        self.results = []
    
    def analyze_pair(self,
                    x: str,
                    y: str,
                    methods: List[str] = ['dcor', 'mi', 'mic']) -> dict:
        """
        分析一对变量的非线性依赖。
        
        Parameters
        ----------
        x, y : str
            变量名
        methods : list
            要使用的检测方法
            
        Returns
        -------
        dict
            分析结果
        """
        x_vals = self.data[x].values
        y_vals = self.data[y].values
        
        result = {'var1': x, 'var2': y}
        
        if 'dcor' in methods:
            dcor_result = distance_correlation(x_vals, y_vals)
            result['dCor'] = dcor_result['dcor']
        
        if 'mi' in methods:
            mi_result = mutual_info_score(x_vals, y_vals)
            result['MI'] = mi_result['mi_normalized']
        
        if 'mic' in methods:
            mic_result = maximal_information_coefficient(x_vals, y_vals)
            result['MIC'] = mic_result['mic']
        
        self.results.append(result)
        
        if self.verbose:
            print(f"\n非线性依赖分析: {x} vs {y}")
            for key, val in result.items():
                if key not in ['var1', 'var2']:
                    print(f"  {key}: {val:.4f}")
        
        return result
    
    def generate_report(self,
                       columns: Optional[List[str]] = None,
                       top_n: int = 10) -> pd.DataFrame:
        """
        生成非线性依赖检测报告。
        
        Parameters
        ----------
        columns : list, optional
            要分析的列
        top_n : int, default=10
            显示前N个结果
            
        Returns
        -------
        pd.DataFrame
            检测报告
        """
        report = nonlinear_dependency_report(
            self.data, columns=columns, top_n=top_n,
            sample_size=0, verbose=False
        )
        
        if self.verbose:
            print("\n非线性依赖检测报告（Top {}）:".format(top_n))
            print(report.to_string(index=False))
        
        return report



"""核心分析模块"""
from .analyzer import quick_corr, CorrAnalyzer
from .partial_corr import (
    partial_corr, 
    partial_corr_matrix, 
    semipartial_corr,
    PartialCorrAnalyzer
)
from .nonlinear import (
    distance_correlation, 
    mutual_info_score,
    maximal_information_coefficient,
    nonlinear_dependency_report,
    NonlinearAnalyzer
)
from .cca import (
    cca,
    cca_permutation_test,
    CCAAnalyzer
)

__all__ = [
    'quick_corr',
    'CorrAnalyzer',
    'partial_corr',
    'partial_corr_matrix',
    'semipartial_corr',
    'PartialCorrAnalyzer',
    'distance_correlation',
    'mutual_info_score',
    'maximal_information_coefficient',
    'nonlinear_dependency_report',
    'NonlinearAnalyzer',
    'cca',
    'cca_permutation_test',
    'CCAAnalyzer',
]



"""
相关性分析核心模块
==================
提供自动化的相关性分析功能，包括自动方法选择、批量计算、可视化等。
"""


from typing import Union, Dict, List, Optional, Tuple, TYPE_CHECKING
import numpy as np
import pandas as pd
from scipy import stats

from ..utils.data_utils import (
    load_data, infer_types, handle_missing, 
    detect_outliers, get_column_pairs,
    is_large_data, estimate_memory_usage
)
from ..utils.stats_utils import (
    check_normality, correct_pvalues, cramers_v,
    eta_coefficient, point_biserial, interpret_correlation
)
from ..utils.large_data import (
    LargeDataConfig, smart_sample, chunked_correlation, optimize_dataframe
)
from .visualizer import CorrVisualizer
from .reporter import CorrReporter

if TYPE_CHECKING:
    import polars as pl


class CorrAnalyzer:
    """
    相关性分析器类
    
    提供完整的相关性分析流程，包括数据预处理、自动方法选择、
    批量计算、可视化和报告生成。
    
    Parameters
    ----------
    data : pd.DataFrame
        输入数据
    method : str, default='auto'
        相关性计算方法：'auto'（自动选择）、'pearson'、'spearman'、'kendall'
    missing_strategy : str, default='warn'
        缺失值处理策略：'warn'、'drop'、'fill'
    fill_method : str, optional
        填充方法：'mean'、'median'、'mode'、'knn'
    pvalue_correction : str, default='fdr_bh'
        p值校正方法
    verbose : bool, default=True
        是否输出详细信息
    large_data_config : LargeDataConfig, optional
        大数据处理配置，用于优化大数据集的计算效率
        
    Examples
    --------
    >>> analyzer = CorrAnalyzer(df)
    >>> result = analyzer.fit()
    >>> analyzer.plot_heatmap()
    
    >>> # 大数据集优化
    >>> from pycorrana.utils import LargeDataConfig
    >>> config = LargeDataConfig(sample_size=100000, auto_sample=True)
    >>> analyzer = CorrAnalyzer(large_df, large_data_config=config)
    """
    
    def __init__(self, 
                 data: pd.DataFrame,
                 method: str = 'auto',
                 missing_strategy: str = 'warn',
                 fill_method: Optional[str] = None,
                 pvalue_correction: str = 'fdr_bh',
                 verbose: bool = True,
                 large_data_config: Optional[LargeDataConfig] = None):
        
        self.original_data = data.copy()
        self.data = data.copy()
        self.method = method
        self.missing_strategy = missing_strategy
        self.fill_method = fill_method
        self.pvalue_correction = pvalue_correction
        self.verbose = verbose
        
        self.large_data_config = large_data_config
        self._is_large_data = False
        self._sampled = False
        
        self.type_mapping = {}
        self.corr_matrix = None
        self.pvalue_matrix = None
        self.confidence_interval_matrix = None
        self.significant_pairs = []
        self.methods_used = {}
        
        self.visualizer = CorrVisualizer()
        self.reporter = CorrReporter()
        
        if self.verbose:
            print("=" * 60)
            print("PyCorrAna - 相关性分析器")
            print("=" * 60)
            
            mem_mb = estimate_memory_usage(self.data)
            print(f"数据规模: {len(self.data):,} 行, {len(self.data.columns)} 列, {mem_mb:.1f} MB")
            
            if is_large_data(self.data):
                self._is_large_data = True
                print("⚠️ 检测到大数据集，将使用优化策略")
                if self.large_data_config is None:
                    self.large_data_config = LargeDataConfig(verbose=self.verbose)
    
    def preprocess(self) -> 'CorrAnalyzer':
        """
        数据预处理：类型推断、缺失值处理、大数据优化。
        
        Returns
        -------
        self
        """
        if self.verbose:
            print("\n[1/4] 数据预处理...")
        
        if self._is_large_data and self.large_data_config:
            if self.large_data_config.auto_optimize:
                self.data = optimize_dataframe(self.data, verbose=self.verbose)
            
            if self.large_data_config.auto_sample:
                self.data, self._sampled = self.large_data_config.prepare_data(self.data)
                if self._sampled:
                    self.original_data = self.data.copy()
        
        self.type_mapping = infer_types(self.data)
        
        if self.verbose:
            print(f"  检测到 {len(self.data)} 行, {len(self.data.columns)} 列")
            if self._sampled:
                print(f"  (已采样，原始数据: {len(self.original_data):,} 行)")
            type_counts = {}
            for t in self.type_mapping.values():
                type_counts[t] = type_counts.get(t, 0) + 1
            for t, count in type_counts.items():
                print(f"  - {t}: {count} 列")
        
        if self.missing_strategy != 'warn':
            self.data = handle_missing(
                self.data, 
                strategy=self.missing_strategy,
                fill_method=self.fill_method,
                verbose=self.verbose
            )
        else:
            missing_ratio = self.data.isnull().sum() / len(self.data)
            if missing_ratio.any() and self.verbose:
                print("\n  ⚠️ 缺失值预警:")
                for col, ratio in missing_ratio[missing_ratio > 0].items():
                    print(f"     {col}: {ratio:.2%}")
        
        return self
    
    def compute_correlation(self, 
                           target: Optional[str] = None,
                           columns: Optional[List[str]] = None) -> 'CorrAnalyzer':
        """
        计算相关性矩阵。
        
        Parameters
        ----------
        target : str, optional
            目标变量，如果指定则只计算与目标变量的相关性
        columns : list, optional
            指定要分析的列
            
        Returns
        -------
        self
        """
        if self.verbose:
            print("\n[2/4] 计算相关性...")
        
        # 选择列
        if columns:
            self.data = self.data[columns]
            self.type_mapping = {k: v for k, v in self.type_mapping.items() 
                               if k in columns}
        
        # 获取所有列对
        pairs = get_column_pairs(self.data, self.type_mapping, target)
        
        if self.verbose:
            print(f"  需要计算 {len(pairs)} 对变量的相关性")
        
        # 初始化结果矩阵
        all_cols = [target] if target else list(self.data.columns)
        if not target:
            all_cols = list(self.data.columns)
        
        n_cols = len(all_cols)
        corr_array = np.full((n_cols, n_cols), np.nan, dtype=np.float64)
        pvalue_array = np.full((n_cols, n_cols), np.nan, dtype=np.float64)
        ci_array = np.full((n_cols, n_cols), np.nan, dtype=object)
        
        self.corr_matrix = pd.DataFrame(corr_array, index=all_cols, columns=all_cols)
        self.pvalue_matrix = pd.DataFrame(pvalue_array, index=all_cols, columns=all_cols)
        self.confidence_interval_matrix = pd.DataFrame(ci_array, index=all_cols, columns=all_cols)
        
        # 对角线为1
        for i in range(n_cols):
            self.corr_matrix.iloc[i, i] = 1.0
            self.pvalue_matrix.iloc[i, i] = 0.0
        
        # 批量计算
        pvalues_list = []
        pairs_list = []
        
        for col1, col2, pair_type in pairs:
            corr_val, p_val, method_used, ci = self._compute_pair(col1, col2, pair_type)
            
            self.corr_matrix.loc[col1, col2] = corr_val
            self.corr_matrix.loc[col2, col1] = corr_val
            self.pvalue_matrix.loc[col1, col2] = p_val
            self.pvalue_matrix.loc[col2, col1] = p_val
            self.confidence_interval_matrix.loc[col1, col2] = ci
            self.confidence_interval_matrix.loc[col2, col1] = ci
            
            self.methods_used[f"{col1}-{col2}"] = method_used
            
            pvalues_list.append(p_val)
            pairs_list.append((col1, col2, corr_val, p_val, ci))
        
        # p值校正
        if pvalues_list and self.pvalue_correction:
            corrected_pvalues = correct_pvalues(pvalues_list, self.pvalue_correction)
            
            # 更新显著性对列表
            for i, (col1, col2, corr_val, orig_p, ci) in enumerate(pairs_list):
                corr_p = corrected_pvalues[i] if i < len(corrected_pvalues) else orig_p
                
                if corr_p < 0.05:  # 显著性水平
                    self.significant_pairs.append({
                        'var1': col1,
                        'var2': col2,
                        'correlation': corr_val,
                        'p_value': corr_p,
                        'confidence_interval': ci,
                        'method': self.methods_used.get(f"{col1}-{col2}", "unknown"),
                        'interpretation': interpret_correlation(corr_val)
                    })
        
        # 按相关性强度排序
        self.significant_pairs.sort(key=lambda x: abs(x['correlation']), reverse=True)
        
        if self.verbose:
            print(f"  完成计算，发现 {len(self.significant_pairs)} 对显著相关变量")
        
        return self
    
    def _compute_pair(self, col1: str, col2: str, 
                     pair_type: str) -> Tuple[float, float, str, Optional[Tuple[float, float]]]:
        """
        计算单个变量对的相关性。
        
        Returns
        -------
        tuple
            (相关系数, p值, 使用的方法, 置信区间)
        """
        x = self.data[col1].dropna()
        y = self.data[col2].dropna()
        
        # 对齐数据
        common_idx = x.index.intersection(y.index)
        x = x.loc[common_idx]
        y = y.loc[common_idx]
        
        if len(x) < 3:
            return np.nan, np.nan, "insufficient_data", None
        
        # 计算置信区间的辅助函数
        def compute_confidence_interval(r, n, method='pearson'):
            """计算相关系数的95%置信区间"""
            if abs(r) == 1:
                return (r, r)
            
            # Fisher变换
            z = np.arctanh(r)
            se = 1 / np.sqrt(n - 3)
            z_crit = stats.norm.ppf(0.975)
            
            # 计算置信区间
            ci_lower = np.tanh(z - z_crit * se)
            ci_upper = np.tanh(z + z_crit * se)
            
            # 限制在[-1, 1]范围内
            ci_lower = max(-1, ci_lower)
            ci_upper = min(1, ci_upper)
            
            return (ci_lower, ci_upper)
        
        # 根据配对类型选择方法
        if self.method == 'auto':
            if pair_type == 'numeric_numeric':
                # 数值+数值：检查正态性
                x_normal = check_normality(x)
                y_normal = check_normality(y)
                
                if x_normal and y_normal:
                    # Pearson
                    r, p = stats.pearsonr(x, y)
                    ci = compute_confidence_interval(r, len(x), 'pearson')
                    return r, p, "pearson", ci
                else:
                    # Spearman更稳健
                    r, p = stats.spearmanr(x, y)
                    ci = compute_confidence_interval(r, len(x), 'spearman')
                    return r, p, "spearman", ci
            
            elif pair_type == 'numeric_binary':
                # 数值+二分类：点双列相关
                r, p = point_biserial(x, y)
                ci = compute_confidence_interval(r, len(x))
                return r, p, "point_biserial", ci
            
            elif pair_type == 'numeric_categorical':
                # 数值+多分类：Eta系数
                eta, p = eta_coefficient(x, y)
                # Eta系数的置信区间计算（近似）
                ci = compute_confidence_interval(eta, len(x))
                return eta, p, "eta", ci
            
            elif pair_type == 'categorical_categorical':
                # 分类+分类：Cramér's V
                v, p = cramers_v(x, y)
                # Cramér's V的置信区间计算（近似）
                ci = compute_confidence_interval(v, len(x))
                return v, p, "cramers_v", ci
            
            elif pair_type == 'ordinal_ordinal':
                # 有序+有序：Kendall's Tau
                tau, p = stats.kendalltau(x, y)
                # Kendall's Tau的置信区间
                n = len(x)
                if n > 10:
                    # 使用正态近似
                    se = 1 / np.sqrt(n * (n - 1) / 2 - 1)
                    z_crit = stats.norm.ppf(0.975)
                    ci_lower = max(-1, tau - z_crit * se)
                    ci_upper = min(1, tau + z_crit * se)
                    ci = (ci_lower, ci_upper)
                else:
                    ci = (np.nan, np.nan)
                return tau, p, "kendall", ci
            
            else:
                # 默认使用Spearman
                r, p = stats.spearmanr(x, y)
                ci = compute_confidence_interval(r, len(x), 'spearman')
                return r, p, "spearman", ci
        
        else:
            # 使用用户指定的方法
            # 先转换为数值类型
            x = pd.to_numeric(x, errors='coerce')
            y = pd.to_numeric(y, errors='coerce')
            
            # 移除NaN
            valid_mask = ~(x.isna() | y.isna())
            x = x[valid_mask]
            y = y[valid_mask]
            
            if len(x) < 3:
                return np.nan, np.nan, "insufficient_data", None
            
            if self.method == 'pearson':
                r, p = stats.pearsonr(x, y)
                ci = compute_confidence_interval(r, len(x), 'pearson')
            elif self.method == 'spearman':
                r, p = stats.spearmanr(x, y)
                ci = compute_confidence_interval(r, len(x), 'spearman')
            elif self.method == 'kendall':
                tau, p = stats.kendalltau(x, y)
                # Kendall's Tau的置信区间
                n = len(x)
                if n > 10:
                    se = 1 / np.sqrt(n * (n - 1) / 2 - 1)
                    z_crit = stats.norm.ppf(0.975)
                    ci_lower = max(-1, tau - z_crit * se)
                    ci_upper = min(1, tau + z_crit * se)
                    ci = (ci_lower, ci_upper)
                else:
                    ci = (np.nan, np.nan)
                r = tau
            else:
                raise ValueError(f"未知的方法: {self.method}")
            
            return r, p, self.method, ci
    
    def fit(self, target: Optional[str] = None,
            columns: Optional[List[str]] = None) -> Dict:
        """
        执行完整分析流程。
        
        Parameters
        ----------
        target : str, optional
            目标变量
        columns : list, optional
            指定列
            
        Returns
        -------
        dict
            分析结果字典
        """
        self.preprocess()
        self.compute_correlation(target=target, columns=columns)
        
        if self.verbose:
            print("\n[3/4] 分析完成！")
        
        return {
            'correlation_matrix': self.corr_matrix,
            'pvalue_matrix': self.pvalue_matrix,
            'confidence_interval_matrix': self.confidence_interval_matrix,
            'significant_pairs': self.significant_pairs,
            'methods_used': self.methods_used,
            'type_mapping': self.type_mapping
        }
    
    def plot_heatmap(self, 
                    figsize: Tuple[int, int] = (10, 8),
                    annot: bool = True,
                    cmap: str = 'RdBu_r',
                    cluster: bool = False,
                    savefig: Optional[str] = None,
                    **kwargs):
        """
        绘制相关性热力图。
        
        Parameters
        ----------
        figsize : tuple, default=(10, 8)
            图表大小
        annot : bool, default=True
            是否显示数值标注
        cmap : str, default='RdBu_r'
            颜色映射
        cluster : bool, default=False
            是否进行层次聚类
        savefig : str, optional
            保存路径
        **kwargs
            其他参数传递给seaborn.heatmap
        """
        if self.corr_matrix is None:
            raise ValueError("请先调用fit()或compute_correlation()")
        
        return self.visualizer.plot_heatmap(
            self.corr_matrix,
            figsize=figsize,
            annot=annot,
            cmap=cmap,
            cluster=cluster,
            savefig=savefig,
            **kwargs
        )
    
    def plot_pairplot(self,
                     columns: Optional[List[str]] = None,
                     hue: Optional[str] = None,
                     savefig: Optional[str] = None,
                     **kwargs):
        """
        绘制散点图矩阵。
        
        Parameters
        ----------
        columns : list, optional
            要绘制的列，默认为所有数值列
        hue : str, optional
            用于颜色区分的列
        savefig : str, optional
            保存路径
        **kwargs
            其他参数
        """
        if columns is None:
            columns = [col for col, t in self.type_mapping.items() 
                      if t == 'numeric']
        
        return self.visualizer.plot_pairplot(
            self.data,
            columns=columns,
            hue=hue,
            savefig=savefig,
            **kwargs
        )
    
    def plot_boxplot(self,
                    numeric_col: str,
                    categorical_col: str,
                    kind: str = 'box',
                    savefig: Optional[str] = None,
                    **kwargs):
        """
        绘制数值变量按分类变量分组的箱线图/小提琴图。
        
        Parameters
        ----------
        numeric_col : str
            数值列名
        categorical_col : str
            分类列名
        kind : str, default='box'
            图表类型：'box'、'violin'、'boxen'
        savefig : str, optional
            保存路径
        **kwargs
            其他参数
        """
        return self.visualizer.plot_boxplot(
            self.data,
            numeric_col=numeric_col,
            categorical_col=categorical_col,
            kind=kind,
            savefig=savefig,
            **kwargs
        )
    
    def export_results(self, 
                      path: str,
                      format: str = 'excel'):
        """
        导出结果。
        
        Parameters
        ----------
        path : str
            保存路径
        format : str, default='excel'
            格式：'excel'、'csv'
        """
        return self.reporter.export_results(
            self.corr_matrix,
            self.pvalue_matrix,
            self.significant_pairs,
            path=path,
            format=format
        )
    
    def summary(self) -> str:
        """
        生成文本摘要。
        
        Returns
        -------
        str
            摘要文本
        """
        return self.reporter.generate_summary(
            self.significant_pairs,
            self.methods_used
        )
    
    def cca(self,
            x_vars: List[str],
            y_vars: List[str],
            compute_significance: bool = True,
            confidence_level: float = 0.95,
            n_permutations: int = 1000) -> Dict:
        """
        执行典型相关分析（Canonical Correlation Analysis, CCA）。
        
        典型相关分析用于研究两组变量之间的线性关系。它寻找两组变量的
        线性组合（典型变量），使得这些组合之间的相关性最大化。
        
        Parameters
        ----------
        x_vars : list
            第一组变量名列表
        y_vars : list
            第二组变量名列表
        compute_significance : bool, default=True
            是否计算显著性检验（p值）
        confidence_level : float, default=0.95
            置信区间水平
        n_permutations : int, default=1000
            置换检验次数
            
        Returns
        -------
        dict
            CCA分析结果，包含：
            - canonical_correlations: 典型相关系数数组
            - x_weights: X的典型变量系数
            - y_weights: Y的典型变量系数
            - x_scores: X的典型变量得分
            - y_scores: Y的典型变量得分
            - significance_tests: 显著性检验结果
            - confidence_intervals: 置信区间
            - redundancy: 冗余分析结果
            
        Examples
        --------
        >>> analyzer = CorrAnalyzer(df)
        >>> analyzer.fit()
        >>> cca_result = analyzer.cca(x_vars=['var1', 'var2'], y_vars=['var3', 'var4'])
        >>> print(cca_result['canonical_correlations'])
        
        References
        ----------
        Hotelling, H. (1936). "Relations between two sets of variates"
        Biometrika, 28(3/4), 321-377
        """
        from .cca import cca as _cca
        
        missing_x = [v for v in x_vars if v not in self.data.columns]
        missing_y = [v for v in y_vars if v not in self.data.columns]
        
        if missing_x:
            raise ValueError(f"X变量不存在于数据中: {missing_x}")
        if missing_y:
            raise ValueError(f"Y变量不存在于数据中: {missing_y}")
        
        X = self.data[x_vars]
        Y = self.data[y_vars]
        
        if self.verbose:
            print(f"\n执行典型相关分析...")
            print(f"  X变量: {x_vars}")
            print(f"  Y变量: {y_vars}")
        
        result = _cca(
            X, Y,
            compute_significance=compute_significance,
            confidence_level=confidence_level,
            n_permutations=n_permutations,
            verbose=self.verbose
        )
        
        return result
    
    def cca_summary(self,
                    x_vars: List[str],
                    y_vars: List[str],
                    compute_significance: bool = True,
                    confidence_level: float = 0.95) -> str:
        """
        执行典型相关分析并生成摘要报告。
        
        Parameters
        ----------
        x_vars : list
            第一组变量名列表
        y_vars : list
            第二组变量名列表
        compute_significance : bool, default=True
            是否计算显著性检验
        confidence_level : float, default=0.95
            置信区间水平
            
        Returns
        -------
        str
            分析摘要文本
        """
        from .cca import CCAAnalyzer
        
        missing_x = [v for v in x_vars if v not in self.data.columns]
        missing_y = [v for v in y_vars if v not in self.data.columns]
        
        if missing_x:
            raise ValueError(f"X变量不存在于数据中: {missing_x}")
        if missing_y:
            raise ValueError(f"Y变量不存在于数据中: {missing_y}")
        
        X = self.data[x_vars]
        Y = self.data[y_vars]
        
        analyzer = CCAAnalyzer(X, Y, verbose=self.verbose)
        analyzer.fit(
            compute_significance=compute_significance,
            confidence_level=confidence_level
        )
        
        return analyzer.summary()
    
    def __repr__(self):
        return f"CorrAnalyzer(data_shape={self.data.shape}, method='{self.method}')"


def quick_corr(data: Union[str, pd.DataFrame, "pl.DataFrame"],
               target: Optional[str] = None,
               columns: Optional[List[str]] = None,
               method: str = 'auto',
               missing_strategy: str = 'warn',
               fill_method: Optional[str] = None,
               pvalue_correction: str = 'fdr_bh',
               plot: bool = True,
               export: Union[bool, str] = False,
               verbose: bool = True,
               large_data_config: Optional[LargeDataConfig] = None,
               **kwargs) -> Dict:
    """
    快速相关性分析入口函数。
    
    一键完成数据加载、预处理、相关性计算、可视化和报告生成。
    
    Parameters
    ----------
    data : str, pd.DataFrame, pl.DataFrame
        数据输入（文件路径或DataFrame）
    target : str, optional
        目标变量
    columns : list, optional
        指定分析的列
    method : str, default='auto'
        相关性方法
    missing_strategy : str, default='warn'
        缺失值处理策略
    fill_method : str, optional
        填充方法
    pvalue_correction : str, default='fdr_bh'
        p值校正方法
    plot : bool, default=True
        是否自动绘图
    export : bool or str, default=False
        是否导出结果，可以是文件路径
    verbose : bool, default=True
        是否输出详细信息
    large_data_config : LargeDataConfig, optional
        大数据处理配置，用于优化大数据集的计算效率
    **kwargs
        其他参数
        
    Returns
    -------
    dict
        完整分析结果
        
    Examples
    --------
    >>> # 基本用法
    >>> result = quick_corr('data.csv')
    
    >>> # 指定目标变量
    >>> result = quick_corr(df, target='sales')
    
    >>> # 自定义参数
    >>> result = quick_corr(df, method='spearman', plot=False, export='results.xlsx')
    
    >>> # 大数据集优化
    >>> from pycorrana.utils import LargeDataConfig
    >>> config = LargeDataConfig(sample_size=50000, auto_sample=True)
    >>> result = quick_corr(large_df, large_data_config=config)
    """
    df = load_data(data)
    
    analyzer = CorrAnalyzer(
        data=df,
        method=method,
        missing_strategy=missing_strategy,
        fill_method=fill_method,
        pvalue_correction=pvalue_correction,
        verbose=verbose,
        large_data_config=large_data_config
    )
    
    result = analyzer.fit(target=target, columns=columns)
    
    if plot:
        if verbose:
            print("\n[3/4] 生成可视化...")
        
        if len(analyzer.corr_matrix) > 1:
            analyzer.plot_heatmap()
        
        numeric_cols = [col for col, t in analyzer.type_mapping.items() 
                       if t == 'numeric']
        if len(numeric_cols) >= 2 and len(numeric_cols) <= 6:
            try:
                analyzer.plot_pairplot(columns=numeric_cols)
            except Exception as e:
                if verbose:
                    print(f"  散点图矩阵生成失败: {e}")
    
    if export:
        if verbose:
            print("\n[4/4] 导出结果...")
        
        if isinstance(export, str):
            export_path = export
        else:
            export_path = 'correlation_results.xlsx'
        
        analyzer.export_results(export_path)
    
    # 输出摘要
    if verbose:
        print("\n" + analyzer.summary())
    
    return result



"""命令行工具模块"""
from .main_cli import app as main_app
from .interactive import app as interactive_app
from .main_cli import analyze, clean, partial, nonlinear, info
from .interactive import interactive_mode, start

__all__ = [
    'main_app',
    'interactive_app',
    'analyze',
    'clean',
    'partial',
    'nonlinear',
    'info',
    'interactive_mode',
    'start',
]
